import type { ExtractPropTypes, PropType } from 'vue';
import type { ButtonType } from '../../button';
import type { IconSlotType } from '../../../types';
export declare const Props: {
    /**
     * @description Title
     */
    readonly title: StringConstructor;
    /**
     * @description Confirm button text
     */
    readonly confirmButtonText: StringConstructor;
    /**
     * @description Cancel button text
     */
    readonly cancelButtonText: StringConstructor;
    /**
     * @description Confirm button type
     */
    readonly confirmButtonType: {
        readonly type: PropType<ButtonType>;
        readonly default: "primary";
    };
    /**
     * @description Cancel button type
     */
    readonly cancelButtonType: {
        readonly type: PropType<ButtonType>;
        readonly default: "text";
    };
    /**
     * @description Icon Component
     */
    readonly icon: {
        readonly type: PropType<IconSlotType>;
        readonly default: () => any;
    };
    /**
     * @description Icon color
     */
    readonly iconColor: {
        readonly type: StringConstructor;
        readonly default: "#f90";
    };
    /**
     * @description is hide Icon
     */
    readonly hideIcon: {
        readonly type: BooleanConstructor;
        readonly default: false;
    };
    /**
     * @description delay of disappear, in millisecond
     */
    readonly hideAfter: {
        readonly type: NumberConstructor;
        readonly default: 200;
    };
    /**
     * @description whether popconfirm is teleported to the body
     */
    readonly teleported: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /**
     * @description when popconfirm inactive and `persistent` is `false` , popconfirm will be destroyed
     */
    readonly persistent: BooleanConstructor;
    /**
     * @description popconfirm width, min width 150px
     */
    readonly width: {
        readonly type: PropType<string | number>;
        readonly default: 150;
    };
};
export declare const Emits: {
    /**
     * @description triggers when click confirm button
     */
    confirm: (e: MouseEvent) => boolean;
    /**
     * @description triggers when click cancel button
     */
    cancel: (e: MouseEvent) => boolean;
};
export type PopconfirmProps = ExtractPropTypes<typeof Props>;
export type PopconfirmEmits = typeof Emits;
